@@ -82,7 +82,7 @@ var zoomButton = L.easyButton({
     }]
 }).addTo(map);
 
-var heatmapLayer = L.imageOverlay('data:', [[0, 0], [0, 0]]).addTo(map);
+var heatmapLayer = L.imageOverlay(_TRANSPARENT_IMAGE, [[0, 0], [0, 0]]).addTo(map);
 var markersImageLayer = L.imageOverlay(_TRANSPARENT_IMAGE, [[0, 0], [0, 0]]).addTo(map);
 
 var BoxSelect = L.Map.BoxZoom.extend({
@@ -173,6 +173,7 @@ L.ourMarker = function (latlng, options) {
 };
 
 function add_markers(latlon_data) {
+    latlon_data = latlon_data || [];
     console.info('adding map markers: ' + latlon_data.length);
 
     clear_markers_js();
