@@ -5,7 +5,7 @@ from tempfile import mkstemp
 
 import numpy as np
 
-from AnyQt.QtCore import Qt, QUrl, pyqtSignal, pyqtSlot, QTimer, QT_VERSION_STR, QObject
+from AnyQt.QtCore import Qt, QUrl, pyqtSignal, pyqtSlot, QTimer, QT_VERSION, QObject
 from AnyQt.QtGui import QImage, QPainter, QPen, QBrush, QColor
 from AnyQt.QtWidgets import qApp
 
@@ -19,11 +19,12 @@ from Orange.widgets.utils.itemmodels import DomainModel
 from Orange.widgets.utils.webview import WebviewWidget
 from Orange.widgets.utils.colorpalette import ColorPaletteGenerator, ContinuousPaletteGenerator
 from Orange.widgets.utils.annotated_data import create_annotated_table, ANNOTATED_DATA_SIGNAL_NAME
+from Orange.widgets.widget import Input, Output
 
 from orangecontrib.geo.utils import find_lat_lon
 
 
-if QT_VERSION_STR <= '5.3':
+if QT_VERSION <= 0x050300:
     raise RuntimeError('Map widget only works with Qt 5.3+')
 
 
@@ -232,11 +233,15 @@ class LeafletMap(WebviewWidget):
                 self._raw_color_values = values = self.data.get_column_view(variable)[0].astype(float)
                 self._scaled_color_values = scale(values)
                 self._colorgen = ContinuousPaletteGenerator(*variable.colors)
+
+                colors = [color_to_hex(i) for i in variable.colors[:2]]
+                if variable.colors[2]:  # pass through black
+                    colors.insert(1, 'black')
+
                 min = np.nanmin(values)
-                self._legend_colors = (['c',
-                                        self._legend_values(variable, [min, np.nanmax(values)]),
-                                        [color_to_hex(i) for i in variable.colors if i]]
-                                       if not np.isnan(min) else [])
+                self._legend_colors = (
+                    ['c', self._legend_values(variable, [min, np.nanmax(values)]), colors]
+                    if not np.isnan(min) else [])
             elif variable.is_discrete:
                 _values = np.asarray(self.data.domain[attr].values)
                 __values = self.data.get_column_view(variable)[0].astype(np.uint16)
@@ -560,6 +565,7 @@ class LeafletMap(WebviewWidget):
                 self._owwidget.progressBarAdvance(100 / n_iters, None)
             else:
                 self._owwidget.progressBarFinished(None)
+                self._image_token = None
 
         self._owwidget.progressBarFinished(None)
         self._owwidget.progressBarInit(None)
@@ -582,12 +588,14 @@ class OWMap(widget.OWWidget):
     icon = "icons/GeoMap.svg"
     priority = 100
 
-    inputs = [("Data", Table, "set_data", widget.Default),
-              ("Data Subset", Table, "set_subset"),
-              ("Learner", Learner, "set_learner")]
+    class Inputs:
+        data = Input("Data", Table, default=True)
+        data_subset = Input("Data Subset", Table)
+        learner = Input("Learner", Learner)
 
-    outputs = [("Selected Data", Table, widget.Default),
-               (ANNOTATED_DATA_SIGNAL_NAME, Table)]
+    class Outputs:
+        selected_data = Output("Selected Data", Table, default=True)
+        annotated_data = Output(ANNOTATED_DATA_SIGNAL_NAME, Table)
 
     replaces = [
         "Orange.widgets.visualize.owmap.OWMap",
@@ -641,7 +649,7 @@ class OWMap(widget.OWWidget):
 
     def __init__(self):
         super().__init__()
-        self.map = map = LeafletMap(self)
+        self.map = map = LeafletMap(self)  # type: LeafletMap
         self.mainArea.layout().addWidget(map)
         self.selection = None
         self.data = None
@@ -780,10 +788,10 @@ class OWMap(widget.OWWidget):
         self.map = None
 
     def commit(self):
-        self.send('Selected Data', self.selection)
-        self.send(ANNOTATED_DATA_SIGNAL_NAME,
-                  create_annotated_table(self.data, self._indices))
+        self.Outputs.selected_data.send(self.selection)
+        self.Outputs.annotated_data.send(create_annotated_table(self.data, self._indices))
 
+    @Inputs.data
     def set_data(self, data):
         self.data = data
 
@@ -829,6 +837,7 @@ class OWMap(widget.OWWidget):
         self.map.set_marker_shape(self.shape_attr, update=False)
         self.map.set_marker_size(self.size_attr, update=True)
 
+    @Inputs.data_subset
     def set_subset(self, subset):
         self.map.set_subset_ids(subset.ids if subset is not None else np.array([]))
 
@@ -836,6 +845,7 @@ class OWMap(widget.OWWidget):
         super().handleNewSignals()
         self.train_model()
 
+    @Inputs.learner
     def set_learner(self, learner):
         self.learner = learner
         self.controls.class_attr.setEnabled(learner is not None)
@@ -881,23 +891,22 @@ class OWMap(widget.OWWidget):
         self.label_attr = self.shape_attr = self.size_attr = None
 
 
-def test_main():
+def main():
     from AnyQt.QtWidgets import QApplication
-    from Orange.regression import KNNRegressionLearner as Learner
-    from Orange.classification import KNNLearner as Learner
+    from Orange.modelling import KNNLearner as Learner
     a = QApplication([])
 
     ow = OWMap()
     ow.show()
     ow.raise_()
-    data = Table('philadelphia-crime')
+    data = Table("India_census_district_population")
     ow.set_data(data)
 
-    QTimer.singleShot(10, lambda: ow.set_learner(Learner(20)))
+    QTimer.singleShot(10, lambda: ow.set_learner(Learner()))
 
     ow.handleNewSignals()
     a.exec()
     ow.saveSettings()
 
 if __name__ == "__main__":
-    test_main()
+    main()
